@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for sagemaker-runtime service client
 
@@ -7,17 +8,14 @@ Usage::
     import boto3
     from mypy_boto3_sagemaker_runtime import SageMakerRuntimeClient
 
-    session = boto3.Session()
-
     client: SageMakerRuntimeClient = boto3.client("sagemaker-runtime")
-    session_client: SageMakerRuntimeClient = session.client("sagemaker-runtime")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING, Type
-from botocore.exceptions import ClientError as Boto3ClientError
-from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
+from typing import IO, Any, Dict, Type, Union
 
+from botocore.exceptions import ClientError as Boto3ClientError
+
+from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
 
 __all__ = ("SageMakerRuntimeClient",)
 
@@ -32,14 +30,14 @@ class Exceptions:
 
 class SageMakerRuntimeClient:
     """
-    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -50,13 +48,13 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
         """
 
     def invoke_endpoint(
         self,
         EndpointName: str,
-        Body: bytes,
+        Body: Union[bytes, IO[bytes]],
         ContentType: str = None,
         Accept: str = None,
         CustomAttributes: str = None,
@@ -64,5 +62,5 @@ class SageMakerRuntimeClient:
         TargetVariant: str = None,
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.25/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
         """
